Learn R Programming

pauwels2014 (version 1.0)

experiment_list1: Molecular perturbations.

Description

A list of functions that represent possible molecular perturbations to be performed on the network.

Usage

data(experiment_list1)

Arguments

Details

A list of 10 functions. Each function takes as input a named numeric parameter vector theta and an initial condition named numeric vector initial_conditions. Each function outputs a list with the following slots:
  • theta: A modified parameter value
  • initial_conditions: A modified initial condition value
  • cost: The cost of the associated molecular perturbation

The 10 functions perform the following operations on their input (parameters numbering might not be always coherent with names):

  • delete_gene6
    • theta: set pro6_strength and rbs6_strength
    • initial_condtions: set p6 initial concentration to 0
    • cost: 800

  • delete_gene7
    • theta: set pro7_strength and rbs8_strength
    • initial_condtions: set p7 initial concentration to 0
    • cost: 800
  • delete_gene8
    • theta: set pro7_strength and rbs8_strength
    • initial_condtions: set p7 initial concentration to 0
    • cost: 800
  • knockdown_gene6
    • theta: multiply mrna6_degradation_rate by 10
    • initial_condtions: Nn operation
    • cost: 350
  • knockdown_gene7
    • theta: multiply mrna7_degradation_rate by 10
    • initial_condtions: no operation
    • cost: 350
  • knockdown_gene8
    • theta: multiply mrna8_degradation_rate by 10
    • initial_condtions: no operation
    • cost: 350
  • decrease_rbs_gene6
    • theta: divide rbs6_strength by 10
    • initial_condtions: no operation
    • cost: 350
  • decrease_rbs_gene7
    • theta: divide rbs6_strength by 10
    • initial_condtions: no operation
    • cost: 350
  • decrease_rbs_gene8
    • theta: divide rbs7_strength by 10
    • initial_condtions: no operation
    • cost: 350
  • nothing
    • theta: no operation
    • initial_condtions: no operation
    • cost: 0
  • Examples

    Run this code
    data(experiment_list1)
    data(knobjs)
    sapply(	
    	1:length(knobjs),
    	function(k){
    		assign(names(knobjs)[k], knobjs[[k]], envir = .GlobalEnv)
    	}
    )
    
    theta <- knobjActMult1$datas[[1]]$thetas[1,]
    thetaT <- knobjActMult1$transform_params(theta)
    
    temp <- experiment_list1$delete_gene7(thetaT, knobjActMult1$global_parameters$initial_conditions)
    
    rbind(temp$theta, thetaT)
    rbind(temp$initial_conditions, knobjActMult1$global_parameters$initial_conditions)
    
    

    Run the code above in your browser using DataLab