Learn R Programming

pauwels2014 (version 1.0)

exps: List of possible experiments

Description

An experiment associates a molecular perturbation and a quantity to observe.

Usage

data(exps)

Arguments

Format

A data frame that combines all possible experiments of experiment_list1 to all possible observations of observables.

Details

The data frame contains 49 entries of the following variables
  • Measurement: a factor with levels "mrnaHigh", "mrnaLow", "p6", "p7", "p8". See observables
  • Cost: a numeric vector. The cost of the corresponding experiment and observation to be performed.
  • exp: a factor with levels "decrease_rbs_gene6", "decrease_rbs_gene7", "decrease_rbs_gene8", "delete_gene6", "delete_gene7", "delete_gene8", "knockdown_gene6", "knockdown_gene7", "knockdown_gene8", "nothing". See experiment_list1 for a description of the corresponding perturbations

This should be 50 experiments by default (10 experiments and 5 observables). However, we always initialise the design process with experiment nothing and observable mrnaLow, this leaves 49 possible experiments left. This object is used by the random_design function.

Examples

Run this code
data(exps)
exps[1,]

Run the code above in your browser using DataLab