Learn R Programming

pauwels2014 (version 1.0)

knobjs: Knowledge lists

Description

A list of knwoledge list

Usage

data(knobjs)

Arguments

Format

A list of lists that were generated using generate_our_knowledge function and updated using different strategy functions and sampling functions. The name of the object defines which strategy and which sampling function was used: The integer at the end of the name is the random number generator seed used to perform the corresponding simulation.

Details

The update performed by the strategies consists in filling the experiments slot of knobj with the sequence experiments performed. See exps. The corresponding data is available in the datas slot. This slot is a list. Each element of this list is a list with the following entries
  • manip: the molecular perturbation performed, an element of experiment_list1
  • data: the associated noisy observations, based on the chosen observable, an element of observables
  • thetas: a posterior sample generated by the corresponding sample_function.
  • risks: the risk associated to all potential new experiments computed by estimate_risk_out_all

The knowledge lists updated using random_design strategy do not provide any risk information.

Examples

Run this code
data(knobjs)
names(knobjs)

sapply(	
	1:length(knobjs),
	function(k){
		assign(names(knobjs)[k], knobjs[[k]], envir = .GlobalEnv)
	}
)
ls()

Run the code above in your browser using DataLab