Learn R Programming

pauwels2014 (version 1.0)

log_likelihood: User defined likelihood function.

Description

Noise is assumed to be independent for each entry. The default likelihood assumes the same heteroscedastic noise as the model used in add_noise.

Usage

log_likelihood(simu, simu_subset, data, fit = F)

Arguments

simu
Simulated time courses.
simu_subset
Subset of the simulated time course which relates to observed data.
data
Observed data.
fit
Should smoothness prior information about simulation added to the prior or not?

Value

A numerical value.

Details

The noise model is gaussian with variance of the form (0.01 + 0.04 * m^2) where m is the mean.

Examples

Run this code
data(experiment_list1)
data(observables)

## Generate the knowledge object with correct parameter value
knobj <- generate_our_knowledge(transform_params)

simu <- simulate_experiment(knobj$global_parameters$true_params_T, knobj, experiment_list1$nothing)

simu_subset <- simu[
 knobj$global_parameters$tspan %in% observables[["mrnaLow"]]$reso, 
 observables[["mrnaLow"]]$obs
]

data <- add_noise(simu_subset)

log_likelihood(simu, simu_subset, data) 

Run the code above in your browser using DataLab