Learn R Programming

pauwels2014 (version 1.0)

log_prior: User defined log prior

Description

User defined log prior based on the parameter value only.

Usage

log_prior(theta)

Arguments

theta
A parameter named numeric vector.

Value

A numerical value

Details

The default is a gaussian prior with large covariance matrix. This is actually a prior on the parameters in log space. The prior can can thus be thought of as a log normal prior.

Examples

Run this code
theta <- 50 + sample(c(0,1), size = 34, replace = TRUE)
log_prior(theta)

Run the code above in your browser using DataLab