Learn R Programming

pauwels2014 (version 1.0)

observables: Observable quantities of the model

Description

A list of quantities that can be observed. Each entry describes the quantity to observe and its time resolution as well as the cost of the corresponding observation.

Usage

data(observables)

Arguments

Format

A list with the follwing entries: "p6", "p7", "p8", "mrnaHigh", "mrnaLow". Each of those entries is a list with the following slots:
  • name: (chr) name of the observable
  • obs: (chr) the subset of kinetic variables to observe
  • reso: (num) time points to observe
  • cost: (nul) the cost of observing this quantity

Details

The complete description of the list is as follows
  • "p6":
    • name: "p6"
    • obs: c("time", "p6")
    • reso: from 0 to 100 by steps of 0.5
    • cost: 400

  • "p7":
    • name: "p7"
    • obs: c("time", "p7")
    • reso: from 0 to 100 by steps of 0.5
    • cost: 400

  • "p8":
    • name: "p8"
    • obs: c("time", "p8")
    • reso: from 0 to 100 by steps of 0.5
    • cost: 400

  • "mrnaHigh":
    • name: "mrnaHigh"
    • obs: c("time", "v6_mrna", "v7_mrna", "v8_mrna")
    • reso: from 0 to 100 by steps of 2
    • cost: 1000

  • "mrnaLow":
    • name: "mrnaLow"
    • obs: c("time", "v6_mrna", "v7_mrna", "v8_mrna")
    • reso: from 0 to 100 by steps of 4
    • cost: 500

Examples

Run this code
data(observables)
data(knobjs)
sapply(	
	1:length(knobjs),
	function(k){
		assign(names(knobjs)[k], knobjs[[k]], envir = .GlobalEnv)
	}
)
data(exps)

theta <- knobjActMult1$datas[[1]]$thetas[1,]
thetaT <- knobjActMult1$transform_params(theta)

temp <- simulate_experiment_no_transform(thetaT, 
	knobjActMult1$global_parameters$initial_conditions, knobjActMult1)

observable <- observables$mrnaLow
temp[temp[,1] %in% observable$reso, colnames(temp) %in% observable$obs]

Run the code above in your browser using DataLab