Learn R Programming

pauwels2014 (version 1.0)

read_knobjs: Summarizes pre-computed results.

Description

Allows to reproduce the figures of the paper (see also vignette).

Usage

read_knobjs(objs)

Arguments

objs
A table of strings representing names of objects given in knobjs.

Value

A list of tables, one for each string. For each of them, the first line is the risk of the posterior sample mean and the second line is the credit spent.

Details

The function computes the risk of the estimated posterior mean as a function of credit spent for each object.

See Also

knobjs

Examples

Run this code
data(knobjs)
data(exps)
sapply(	
	1:length(knobjs),
	function(k){
		assign(names(knobjs)[k], knobjs[[k]], envir = .GlobalEnv)
	}
)

read_knobjs(paste("knobjActMult", 1:10, sep=""))

Run the code above in your browser using DataLab