data(exps)experiment_list1 to all possible observations of observables.Measurement: a factor with levels "mrnaHigh", "mrnaLow", "p6", "p7", "p8". See observables
Cost: a numeric vector. The cost of the corresponding experiment and observation to be performed.
exp: a factor with levels "decrease_rbs_gene6", "decrease_rbs_gene7", "decrease_rbs_gene8", "delete_gene6", "delete_gene7", "delete_gene8", "knockdown_gene6", "knockdown_gene7", "knockdown_gene8", "nothing". See experiment_list1 for a description of the corresponding perturbations
This should be 50 experiments by default (10 experiments and 5 observables). However, we always initialise the design process with experiment nothing and observable mrnaLow, this leaves 49 possible experiments left. This object is used by the random_design function.