generate_our_knowledge(transform_params, global_parameters, datas)transform_params.
datas slot.
deSolve parameter (see deSolve)deSolve parameter (see deSolve)deSolve parameter, the time points at which all simulated kinetic quantities should be evaluateddeSolve parameter (see deSolve)BFGS_special functionBFGS_special functionBFGS_special functionBFGS_special functionsample_function_multi_mod_weight functionsample_function_multi_mod_weight function and in sample_function_single_mod functionsample_function_multi_mod_weight function and in sample_function_single_mod functiongenerate_samplegenerate_samplegenerate_sample functionsample_function_multi_mod_weight and sample_function_single_mod. This is the size of the sample that is to be stored in the knowledge list.active_design strategy.active_design strategy.transform_params(true_params_T) = true_paramsdeSolve solver. See the vignette and deSolve package for more details. The default is "pauwels2014" as the source for the example of the article is provided in this package.transform_params which is by default a log transformation function that allows to work in log space. See transform_params. The second slot, global_parameters contains various global parameters necessary for the simulation to proceed. The default value of those parameters is given in the next section. See also the vignette for details. The third slot is named datas. It is empty by default, but is intended to receive datasets, experiment function, posterior sample and expected risk estimates for each step of the simulation. The vignette provides more details about this.
knobj <- generate_our_knowledge(transform_params)
knobj
Run the code above in your browser using DataLab