Allows to reproduce the figures of the paper (see also vignette).
Usage
read_knobjs(objs)
Arguments
objs
A table of strings representing names of objects given in knobjs.
Value
A list of tables, one for each string. For each of them, the first line is the risk of the posterior sample mean and the second line is the credit spent.
Details
The function computes the risk of the estimated posterior mean as a function of credit spent for each object.